RemoveRecording

Struct RemoveRecording 

pub struct RemoveRecording(pub bool);
Whether to remove records during recording playback.

This option is used for test recordings, if true, the recording will be removed from the test-proxy when retrieved, otherwise it will be kept. The default is true.

Tuple Fields

0: bool