pub struct RemoveRecording(pub bool);Expand description
Whether to remove records during recording playback.
This option is used for test recordings, if true, the recording will be removed from the test-proxy when retrieved, otherwise it will be kept. The default is true.
Tuple Fields
0: boolTrait Implementations
Sourceimpl Debug for RemoveRecording
impl Debug for RemoveRecording
Sourceimpl Header for RemoveRecording
impl Header for RemoveRecording
Sourcefn name(&self) -> HeaderName
fn name(&self) -> HeaderName
Get the name of the header.
Sourcefn value(&self) -> HeaderValue
fn value(&self) -> HeaderValue
Get the value of the header.